uCode CLI tools

CLI tools to prepare problems locally and to work with uCode.vn server

# Description

## DSA problem tools

## Other question tools

## Interact with ucode.vn server

# Installation
 
## Normal installation

```bash
pip install ucode-cli --upgrade
```

## Development installation

```bash
git clone https://gitlab.com/ucodevn/ucode-cli.git
cd ucode-cli
pip install --editable .
```

# Usage
## Get help
```bash
ucode --help
```

## Get help for a specific command
```bash
ucode {command} --help
```